snarkos-cli 4.11.0

Command-line interface for snarkOS
docs.rs failed to build snarkos-cli-4.11.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: snarkos-cli-4.10.0

snarkos-cli

Crates.io Authors License

The snarkos-cli crate provides the CLI struct, which is responsible for providing a command-line interface to the node.