Constants
- DEVELOPMENT_
MODE_ NUM_ GENESIS_ COMMITTEE_ MEMBERS - The development mode number of genesis committee members.
- DEVELOPMENT_
MODE_ RNG_ SEED - The development mode RNG seed.
- DEVNET_
NUM_ VALIDATORS_ PER_ CLIENT - The number of validators a devnet client connects to by default.
Functions
- get_
development_ key - Get the private key for a validator in development mode.
- get_
devnet_ gateway_ address_ for_ validator - Returns the gateway address a particular devnet validator will listen on.
- get_
devnet_ router_ address_ for_ node - Returns the router address a particular devnet validator will list on.
- get_
devnet_ validators_ for_ client - Returns the indicies of validators a particular devnet client will connect to.