Module logger

Module logger 

Functions

initialize_logger
Sets the log filter based on the given verbosity level. Initializes the logger with the specified verbosity level, where 0 is the lowest verbosity and 6 the highest.
initialize_terminal_logger
Set up only terminal logging
welcome_message
Returns the welcome message as a string.