Struct snarkos_cli::commands::Start

source ·
pub struct Start {
Show 25 fields pub network: u16, pub validator: bool, pub prover: bool, pub client: bool, pub private_key: Option<String>, pub private_key_file: Option<PathBuf>, pub node: Option<SocketAddr>, pub bft: Option<SocketAddr>, pub peers: String, pub validators: String, pub allow_external_peers: bool, pub rest: Option<SocketAddr>, pub rest_rps: u32, pub norest: bool, pub nodisplay: bool, pub verbosity: u8, pub logfile: PathBuf, pub metrics: bool, pub storage: Option<PathBuf>, pub cdn: Option<String>, pub nocdn: bool, pub dev: Option<u16>, pub dev_num_validators: Option<u16>, pub no_dev_txs: bool, pub dev_bonded_balances: Option<BondedBalances>,
}
Starts the snarkOS node.

Fields

network: u16

Specify the network ID of this node

validator: bool

Specify this node as a validator

prover: bool

Specify this node as a prover

client: bool

Specify this node as a client

private_key: Option<String>

Specify the account private key of the node

private_key_file: Option<PathBuf>

Specify the path to a file containing the account private key of the node

node: Option<SocketAddr>

Specify the IP address and port for the node server

bft: Option<SocketAddr>

Specify the IP address and port for the BFT

peers: String

Specify the IP address and port of the peer(s) to connect to

validators: String

Specify the IP address and port of the validator(s) to connect to

allow_external_peers: bool

If the flag is set, a node will allow untrusted peers to connect

rest: Option<SocketAddr>

Specify the IP address and port for the REST server

rest_rps: u32

Specify the requests per second (RPS) rate limit per IP for the REST server

norest: bool

If the flag is set, the node will not initialize the REST server

nodisplay: bool

If the flag is set, the node will not render the display

verbosity: u8

Specify the verbosity of the node [options: 0, 1, 2, 3, 4]

logfile: PathBuf

Specify the path to the file where logs will be stored

metrics: bool

Enables the metrics exporter

storage: Option<PathBuf>

Specify the path to a directory containing the storage database for the ledger

cdn: Option<String>

Enables the node to prefetch initial blocks from a CDN

nocdn: bool

If the flag is set, the node will not prefetch from a CDN

dev: Option<u16>

Enables development mode, specify a unique ID for this node

dev_num_validators: Option<u16>

If development mode is enabled, specify the number of genesis validators (default: 4)

no_dev_txs: bool

If developtment mode is enabled, specify whether node 0 should generate traffic to drive the network

dev_bonded_balances: Option<BondedBalances>

If development mode is enabled, specify the custom bonded balances as a JSON object (default: None)

Implementations

source

impl Start

source

pub fn parse(self) -> Result<String>

Starts the snarkOS node.