Struct snarkos_cli::commands::Start
source · pub struct Start {Show 18 fields
pub network: u16,
pub validator: bool,
pub prover: bool,
pub client: bool,
pub private_key: Option<String>,
pub private_key_file: Option<PathBuf>,
pub node: SocketAddr,
pub bft: Option<SocketAddr>,
pub peers: String,
pub validators: String,
pub rest: SocketAddr,
pub norest: bool,
pub nodisplay: bool,
pub verbosity: u8,
pub logfile: PathBuf,
pub cdn: String,
pub dev: Option<u16>,
pub dev_num_validators: Option<u16>,
}Expand description
Starts the snarkOS node.
Fields
network: u16Specify the network ID of this node
validator: boolSpecify this node as a validator
prover: boolSpecify this node as a prover
client: boolSpecify this node as a client
private_key: Option<String>Specify the account private key of the node
private_key_file: Option<PathBuf>Specify the path to a file containing the account private key of the node
node: SocketAddrSpecify the IP address and port for the node server
bft: Option<SocketAddr>Specify the IP address and port for the BFT
peers: StringSpecify the IP address and port of the peer(s) to connect to
validators: StringSpecify the IP address and port of the validator(s) to connect to
rest: SocketAddrSpecify the IP address and port for the REST server
norest: boolIf the flag is set, the node will not initialize the REST server
nodisplay: boolIf the flag is set, the node will not render the display
verbosity: u8Specify the verbosity of the node [options: 0, 1, 2, 3, 4]
logfile: PathBufSpecify the path to the file where logs will be stored
cdn: StringEnables the node to prefetch initial blocks from a CDN
dev: Option<u16>Enables development mode, specify a unique ID for this node
dev_num_validators: Option<u16>If development mode is enabled, specify the number of genesis validators (default: 4)
Implementations