Struct snarkos_cli::commands::Start
source · pub struct Start {Show 14 fields
pub network: u16,
pub beacon: Option<String>,
pub validator: Option<String>,
pub prover: Option<String>,
pub client: Option<String>,
pub node: SocketAddr,
pub connect: String,
pub rest: SocketAddr,
pub norest: bool,
pub nodisplay: bool,
pub verbosity: u8,
pub logfile: PathBuf,
pub cdn: String,
pub dev: Option<u16>,
}Expand description
Starts the snarkOS node.
Fields
network: u16Specify the network ID of this node
beacon: Option<String>Specify this node as a beacon, with the account private key as an argument
validator: Option<String>Specify this node as a validator, with the account private key as an argument
prover: Option<String>Specify this node as a prover, with the account private key as an argument
client: Option<String>Specify this node as a client, with an optional account private key as an argument
node: SocketAddrSpecify the IP address and port for the node server
connect: StringSpecify the IP address and port of a peer to connect to
rest: SocketAddrSpecify the IP address and port for the REST server
norest: boolIf the flag is set, the node will not initialize the REST server
nodisplay: boolIf the flag is set, the node will not render the display
verbosity: u8Specify the verbosity of the node [options: 0, 1, 2, 3, 4]
logfile: PathBufSpecify the path to the file where logs will be stored
cdn: StringEnables the node to prefetch initial blocks from a CDN
dev: Option<u16>Enables development mode, specify a unique ID for this node
Implementations