Module helpers

Re-exports

pub use logger::*;
pub use updater::*;

Modules

logger
updater

Constants

BECH32M_CHARSET

Functions

check_open_files_limit
Check if process’s open files limit is above minimum and warn if not.
has_vanity_string
Check if a given vanity string exists at the start or end of the data part of a bech32m string.
is_in_bech32m_charset
Check if a string is a valid bech32m character set.