Functions
- initialize_
logger - Sets the log filter based on the given verbosity level. Initializes the logger with the specified verbosity level, where 0 is the lowest verbosity and 6 the highest.
- initialize_
terminal_ logger - Set up only terminal logging
- welcome_
message - Returns the welcome message as a string.